@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2013 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -17,7 +17,6 @@ package org.eclipse.core.externaltools.internal.model;
 
 import java.util.Map;
 
-import org.eclipse.core.externaltools.internal.ExternalToolsCore;
 import org.eclipse.core.externaltools.internal.IExternalToolConstants;
 import org.eclipse.core.externaltools.internal.launchConfigurations.ExternalToolsCoreUtil;
 import org.eclipse.core.externaltools.internal.registry.ExternalToolMigration;
@@ -30,20 +29,27 @@ import org.eclipse.core.resources.IResourceDelta;
 import org.eclipse.core.resources.IResourceDeltaVisitor;
 import org.eclipse.core.resources.IncrementalProjectBuilder;
 import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.ILog;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.Platform;
+import org.eclipse.core.runtime.Status;
 import org.eclipse.debug.core.ILaunchConfiguration;
 import org.eclipse.debug.core.ILaunchConfigurationWorkingCopy;
 import org.eclipse.debug.core.ILaunchManager;
 import org.eclipse.osgi.util.NLS;
 import org.osgi.framework.Bundle;
+import org.osgi.framework.FrameworkUtil;
 
 /**
  * This project builder implementation will run an external tool during the
  * build process.
  */
 public final class ExternalToolBuilder extends IncrementalProjectBuilder {
-	private final class IgnoreTeamPrivateChanges implements IResourceDeltaVisitor {
+
+	private static final ILog LOG = Platform.getLog(ExternalToolBuilder.class);
+
+	private static final class IgnoreTeamPrivateChanges implements IResourceDeltaVisitor {
 		private boolean[] fTrueChange;
 		private IgnoreTeamPrivateChanges(boolean[] trueChange) {
 			super();
@@ -65,18 +71,18 @@ public final class ExternalToolBuilder extends IncrementalProjectBuilder {
 	private static String buildType = IExternalToolConstants.BUILD_TYPE_NONE;
 
 	private static IProject buildProject= null;
-    private static IResourceDelta buildDelta= null;
+	private static IResourceDelta buildDelta= null;
 
 	@Override
 	protected IProject[] build(int kind, Map<String, String> args, IProgressMonitor monitor) throws CoreException {
-		if (ExternalToolsCore.getDefault().getBundle().getState() != Bundle.ACTIVE) {
+		if (FrameworkUtil.getBundle(ExternalToolBuilder.class).getState() != Bundle.ACTIVE) {
 			return null;
 		}
 
 		ILaunchConfiguration config= BuilderCoreUtils.configFromBuildCommandArgs(getProject(), args, new String[1]);
-        if (config == null) {
-            throw ExternalToolsCore.newError(ExternalToolsModelMessages.ExternalToolBuilder_0, null);
-        }
+		if (config == null) {
+			throw new CoreException(Status.error(ExternalToolsModelMessages.ExternalToolBuilder_0, null));
+		}
 		IProject[] projectsWithinScope= null;
 		IResource[] resources = ExternalToolsCoreUtil.getResourcesForBuildScope(config);
 		if (resources != null) {
@@ -85,64 +91,64 @@ public final class ExternalToolBuilder extends IncrementalProjectBuilder {
 				projectsWithinScope[i]= resources[i].getProject();
 			}
 		}
-        boolean kindCompatible= commandConfiguredForKind(config, kind);
-        if (kindCompatible && configEnabled(config)) {
-            doBuildBasedOnScope(resources, kind, config, args, monitor);
-        }
+		boolean kindCompatible= commandConfiguredForKind(config, kind);
+		if (kindCompatible && configEnabled(config)) {
+			doBuildBasedOnScope(resources, kind, config, args, monitor);
+		}
 
 		return projectsWithinScope;
 	}
 
-    private boolean commandConfiguredForKind(ILaunchConfiguration config, int kind) {
-        try {
-            if (!(config.getAttribute(IExternalToolConstants.ATTR_TRIGGERS_CONFIGURED, false))) {
-                ICommand command= getCommand();
-                //adapt the builder command to make use of the 3.1 support for setting command build kinds
-                //this will only happen once for builder/command defined before the support existed
-                BuilderCoreUtils.configureTriggers(config, command);
-                IProjectDescription desc= getProject().getDescription();
-                ICommand[] commands= desc.getBuildSpec();
-                int index= getBuilderCommandIndex(commands, command);
-                if (index != -1) {
-                    commands[index]= command;
-                    desc.setBuildSpec(commands);
-                    getProject().setDescription(desc, null);
-                    ILaunchConfigurationWorkingCopy copy= config.getWorkingCopy();
-                    copy.setAttribute(IExternalToolConstants.ATTR_TRIGGERS_CONFIGURED, true);
-                    copy.doSave();
-                }
-                return command.isBuilding(kind);
-            }
-        } catch (CoreException e) {
-           ExternalToolsCore.log(e);
-           return true;
-        }
-        return true;
-    }
+	private boolean commandConfiguredForKind(ILaunchConfiguration config, int kind) {
+		try {
+			if (!(config.getAttribute(IExternalToolConstants.ATTR_TRIGGERS_CONFIGURED, false))) {
+				ICommand command= getCommand();
+				//adapt the builder command to make use of the 3.1 support for setting command build kinds
+				//this will only happen once for builder/command defined before the support existed
+				BuilderCoreUtils.configureTriggers(config, command);
+				IProjectDescription desc= getProject().getDescription();
+				ICommand[] commands= desc.getBuildSpec();
+				int index= getBuilderCommandIndex(commands, command);
+				if (index != -1) {
+					commands[index]= command;
+					desc.setBuildSpec(commands);
+					getProject().setDescription(desc, null);
+					ILaunchConfigurationWorkingCopy copy= config.getWorkingCopy();
+					copy.setAttribute(IExternalToolConstants.ATTR_TRIGGERS_CONFIGURED, true);
+					copy.doSave();
+				}
+				return command.isBuilding(kind);
+			}
+		} catch (CoreException e) {
+			LOG.log(Status.error("Error logged from Ant UI: ", e)); //$NON-NLS-1$
+			return true;
+		}
+		return true;
+	}
 
-    private int getBuilderCommandIndex(ICommand[] buildSpec, ICommand command) {
+	private int getBuilderCommandIndex(ICommand[] buildSpec, ICommand command) {
 		Map<String, String> commandArgs = command.getArguments();
-        if (commandArgs == null) {
-            return -1;
-        }
-        String handle= commandArgs.get(BuilderCoreUtils.LAUNCH_CONFIG_HANDLE);
-        if (handle == null) {
-            return -1;
-        }
-        for (int i = 0; i < buildSpec.length; ++i) {
-            ICommand buildSpecCommand= buildSpec[i];
-            if (ID.equals(buildSpecCommand.getBuilderName())) {
+		if (commandArgs == null) {
+			return -1;
+		}
+		String handle= commandArgs.get(BuilderCoreUtils.LAUNCH_CONFIG_HANDLE);
+		if (handle == null) {
+			return -1;
+		}
+		for (int i = 0; i < buildSpec.length; ++i) {
+			ICommand buildSpecCommand= buildSpec[i];
+			if (ID.equals(buildSpecCommand.getBuilderName())) {
 				Map<String, String> buildSpecArgs = buildSpecCommand.getArguments();
-                if (buildSpecArgs != null) {
-                    String buildSpecHandle= buildSpecArgs.get(BuilderCoreUtils.LAUNCH_CONFIG_HANDLE);
-                    if (handle.equals(buildSpecHandle)) {
-                        return i;
-                    }
-                }
-            }
-        }
-        return -1;
-    }
+				if (buildSpecArgs != null) {
+					String buildSpecHandle= buildSpecArgs.get(BuilderCoreUtils.LAUNCH_CONFIG_HANDLE);
+					if (handle.equals(buildSpecHandle)) {
+						return i;
+					}
+				}
+			}
+		}
+		return -1;
+	}
 
 	/**
 	 * Returns whether the given builder config is enabled or not.
@@ -154,7 +160,7 @@ public final class ExternalToolBuilder extends IncrementalProjectBuilder {
 		try {
 			return ExternalToolsCoreUtil.isBuilderEnabled(config);
 		} catch (CoreException e) {
-			ExternalToolsCore.log(e);
+			LOG.log(Status.error("Error logged from Ant UI: ", e)); //$NON-NLS-1$
 		}
 		return true;
 	}
@@ -204,15 +210,15 @@ public final class ExternalToolBuilder extends IncrementalProjectBuilder {
 		return buildProject;
 	}
 
-    /**
-     * Returns the <code>IResourceDelta</code> that is being built and has triggered the current external
-     * tool builder. <code>null</code> is returned if no build is currently occurring.
-     *
-     * @return resource delta for the build or <code>null</code>
-     */
-    public static IResourceDelta getBuildDelta() {
-        return buildDelta;
-    }
+	/**
+	 * Returns the <code>IResourceDelta</code> that is being built and has triggered the current external
+	 * tool builder. <code>null</code> is returned if no build is currently occurring.
+	 *
+	 * @return resource delta for the build or <code>null</code>
+	 */
+	public static IResourceDelta getBuildDelta() {
+		return buildDelta;
+	}
 
 	/**
 	 * Stores the currently active build kind and build project when a build begins
@@ -238,9 +244,9 @@ public final class ExternalToolBuilder extends IncrementalProjectBuilder {
 				buildType = IExternalToolConstants.BUILD_TYPE_AUTO;
 				buildDelta = getDelta(getProject());
 				break;
-            case IncrementalProjectBuilder.CLEAN_BUILD :
-                buildType = IExternalToolConstants.BUILD_TYPE_CLEAN;
-                break;
+			case IncrementalProjectBuilder.CLEAN_BUILD :
+				buildType = IExternalToolConstants.BUILD_TYPE_CLEAN;
+				break;
 			default :
 				buildType = IExternalToolConstants.BUILD_TYPE_NONE;
 				break;
@@ -254,17 +260,17 @@ public final class ExternalToolBuilder extends IncrementalProjectBuilder {
 	private void buildEnded() {
 		buildType= IExternalToolConstants.BUILD_TYPE_NONE;
 		buildProject= null;
-        buildDelta= null;
+		buildDelta= null;
 	}
 
 	private boolean buildScopeIndicatesBuild(IResource[] resources) {
-		for (int i = 0; i < resources.length; i++) {
-			IResourceDelta delta = getDelta(resources[i].getProject());
+		for (IResource resource : resources) {
+			IResourceDelta delta = getDelta(resource.getProject());
 			if (delta == null) {
 				//project just added to the workspace..no previous build tree
 				return true;
 			}
-			IPath path= resources[i].getProjectRelativePath();
+			IPath path = resource.getProjectRelativePath();
 			IResourceDelta change= delta.findMember(path);
 			if (change != null) {
 				final boolean[] trueChange= new boolean[1];
@@ -272,7 +278,7 @@ public final class ExternalToolBuilder extends IncrementalProjectBuilder {
 				try {
 					change.accept(new IgnoreTeamPrivateChanges(trueChange));
 				} catch (CoreException e) {
-					ExternalToolsCore.log("Internal error resolving changed resources during build", e); //$NON-NLS-1$
+					LOG.log(Status.error("Internal error resolving changed resources during build", e)); //$NON-NLS-1$
 				}
 
 				return trueChange[0]; //filtered out team private changes
@@ -281,20 +287,20 @@ public final class ExternalToolBuilder extends IncrementalProjectBuilder {
 		return false;
 	}
 
-    @Override
+	@Override
 	protected void clean(IProgressMonitor monitor) throws CoreException {
-	    ICommand command= getCommand();
-        ILaunchConfiguration config= BuilderCoreUtils.configFromBuildCommandArgs(getProject(), command.getArguments(), new String[1]);
-    	if (!configEnabled(config)) {
-	    	return;
-	    }
+		ICommand command= getCommand();
+		ILaunchConfiguration config= BuilderCoreUtils.configFromBuildCommandArgs(getProject(), command.getArguments(), new String[1]);
+		if (!configEnabled(config)) {
+			return;
+		}
 
-        if ((!config.getAttribute(IExternalToolConstants.ATTR_TRIGGERS_CONFIGURED, false))) {
-            //old behavior
-            super.clean(monitor);
-            return;
-        }
+		if ((!config.getAttribute(IExternalToolConstants.ATTR_TRIGGERS_CONFIGURED, false))) {
+			//old behavior
+			super.clean(monitor);
+			return;
+		}
 
 		launchBuild(IncrementalProjectBuilder.CLEAN_BUILD, config, null, monitor);
-    }
+	}
 }
\ No newline at end of file
