@@ -27,6 +27,7 @@ import java.util.stream.Collectors;
 
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.Platform;
 import org.eclipse.core.runtime.PlatformObject;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.debug.core.DebugEvent;
@@ -107,6 +108,8 @@ public class RuntimeProcess extends PlatformObject implements IProcess {
 	 */
 	private boolean fTerminateDescendants = true;
 
+	private final String fThreadNameSuffix;
+
 	/**
 	 * Constructs a RuntimeProcess on the given system process
 	 * with the given name, adding this process to the given
@@ -122,6 +125,11 @@ public class RuntimeProcess extends PlatformObject implements IProcess {
 		setLaunch(launch);
 		initializeAttributes(attributes);
 		fProcess = process;
+		try {
+			setAttribute(IProcess.ATTR_PROCESS_ID, Long.toString(process.pid()));
+		} catch (UnsupportedOperationException e) {
+			// ignore, pid() is not implemented in this JVM
+		}
 		fName = name;
 		fTerminated = true;
 		try {
@@ -141,14 +149,26 @@ public class RuntimeProcess extends PlatformObject implements IProcess {
 		} catch (CoreException e) {
 			DebugPlugin.log(e);
 		}
+		fThreadNameSuffix = getPidInfo(process, launch);
 
 		fStreamsProxy = createStreamsProxy();
-		fMonitor = new ProcessMonitorThread();
+		fMonitor = new ProcessMonitorThread(fThreadNameSuffix);
 		fMonitor.start();
 		launch.addProcess(this);
 		fireCreationEvent();
 	}
 
+	private static String getPidInfo(Process process, ILaunch launch) {
+		String pid;
+		ILaunchConfiguration lc = launch == null ? null : launch.getLaunchConfiguration();
+		String name = lc == null ? "" : " " + lc.getName(); //$NON-NLS-1$ //$NON-NLS-2$
+		try {
+			pid = " for PID " + process.pid(); //$NON-NLS-1$
+		} catch (Exception e) {
+			pid = ""; //$NON-NLS-1$
+		}
+		return pid + name;
+	}
 	/**
 	 * Initialize the attributes of this process to those in the given map.
 	 *
@@ -216,37 +236,41 @@ public class RuntimeProcess extends PlatformObject implements IProcess {
 	@Override
 	public void terminate() throws DebugException {
 		if (!isTerminated()) {
-			if (fStreamsProxy instanceof StreamsProxy) {
-				((StreamsProxy) fStreamsProxy).kill();
-			}
-			Process process = getSystemProcess();
-			if (process == null) {
-				return;
-			}
-
-			List<ProcessHandle> descendants = Collections.emptyList();
-			if (fTerminateDescendants) {
-				try { // List of descendants of process is only a snapshot!
-					descendants = process.descendants().collect(Collectors.toList());
-				} catch (UnsupportedOperationException e) {
-					// JVM may not support toHandle() -> assume no descendants
+			try {
+				Process process = getSystemProcess();
+				if (process == null) {
+					return;
 				}
-			}
 
-			process.destroy();
-			descendants.forEach(ProcessHandle::destroy);
-
-			// await termination of process and descendants
-			try { // (in total don't wait longer than TERMINATION_TIMEOUT)
-				long waitStart = System.currentTimeMillis();
-				if (process.waitFor(TERMINATION_TIMEOUT, TimeUnit.MILLISECONDS)) {
-					fExitValue = process.exitValue();
-					if (waitFor(descendants, waitStart)) {
-						return;
+				List<ProcessHandle> descendants = Collections.emptyList();
+				if (fTerminateDescendants) {
+					try { // List of descendants of process is only a snapshot!
+						descendants = process.descendants().collect(Collectors.toList());
+					} catch (UnsupportedOperationException e) {
+						// JVM may not support toHandle() -> assume no
+						// descendants
 					}
 				}
-			} catch (InterruptedException e) {
-				Thread.currentThread().interrupt();
+
+				process.destroy();
+				descendants.forEach(ProcessHandle::destroy);
+
+				// await termination of process and descendants
+				try { // (in total don't wait longer than TERMINATION_TIMEOUT)
+					long waitStart = System.currentTimeMillis();
+					if (process.waitFor(TERMINATION_TIMEOUT, TimeUnit.MILLISECONDS)) {
+						fExitValue = process.exitValue();
+						if (waitFor(descendants, waitStart)) {
+							return;
+						}
+					}
+				} catch (InterruptedException e) {
+					Thread.currentThread().interrupt();
+				}
+			} finally {
+				if (fStreamsProxy instanceof StreamsProxy) {
+					((StreamsProxy) fStreamsProxy).kill();
+				}
 			}
 
 			// clean-up
@@ -346,7 +370,10 @@ public class RuntimeProcess extends PlatformObject implements IProcess {
 				DebugPlugin.log(e);
 			}
 		}
-		return new StreamsProxy(getSystemProcess(), charset);
+		if (charset == null) {
+			charset = Platform.getSystemCharset();
+		}
+		return new StreamsProxy(getSystemProcess(), charset, fThreadNameSuffix);
 	}
 
 	/**
@@ -479,9 +506,11 @@ public class RuntimeProcess extends PlatformObject implements IProcess {
 		/**
 		 * Creates a new process monitor and starts monitoring the process for
 		 * termination.
+		 *
+		 * @param suffix Thread name suffix
 		 */
-		private ProcessMonitorThread() {
-			super(DebugCoreMessages.ProcessMonitorJob_0);
+		private ProcessMonitorThread(String suffix) {
+			super(DebugCoreMessages.ProcessMonitorJob_0 + suffix);
 			setDaemon(true);
 		}
 
