@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -589,6 +589,7 @@ public class LaunchConfiguration extends PlatformObject implements ILaunchConfig
 	public String getMemento() throws CoreException {
 		IPath relativePath = null;
 		IFile file = getFile();
+		String lineDelimeter = getLineSeparator();
 		boolean local = true;
 		if (file == null) {
 			relativePath = new Path(getName());
@@ -603,7 +604,7 @@ public class LaunchConfiguration extends PlatformObject implements ILaunchConfig
 			doc.appendChild(node);
 			node.setAttribute(IConfigurationElementConstants.LOCAL, Boolean.toString(local));
 			node.setAttribute(IConfigurationElementConstants.PATH, relativePath.toString());
-			return LaunchManager.serializeDocument(doc);
+			return LaunchManager.serializeDocument(doc, lineDelimeter);
 		} catch (IOException ioe) {
 			e= ioe;
 		} catch (ParserConfigurationException pce) {
@@ -737,62 +738,64 @@ public class LaunchConfiguration extends PlatformObject implements ILaunchConfig
 			}
 			// allow the delegate to provide a launch implementation
 			ILaunch launch = null;
-			if (delegate2 != null) {
-				launch = delegate2.getLaunch(this, mode);
-			}
-			if (launch == null) {
-				launch = new Launch(this, mode, null);
-			} else // ensure the launch mode is valid
-			if (!mode.equals(launch.getLaunchMode())) {
-				IStatus status = new Status(IStatus.ERROR, DebugPlugin.getUniqueIdentifier(), DebugPlugin.ERROR,
-						MessageFormat.format(DebugCoreMessages.LaunchConfiguration_14, mode, launch.getLaunchMode()), null);
-				throw new CoreException(status);
-			}
-			launch.setAttribute(DebugPlugin.ATTR_LAUNCH_TIMESTAMP, Long.toString(System.currentTimeMillis()));
-			boolean captureOutput = getAttribute(DebugPlugin.ATTR_CAPTURE_OUTPUT, true);
-			if(!captureOutput) {
-				launch.setAttribute(DebugPlugin.ATTR_CAPTURE_OUTPUT, "false"); //$NON-NLS-1$
-			} else {
-				launch.setAttribute(DebugPlugin.ATTR_CAPTURE_OUTPUT, null);
-			}
-			launch.setAttribute(DebugPlugin.ATTR_CONSOLE_ENCODING, getLaunchManager().getEncoding(this));
-			if (register) {
-				getLaunchManager().addLaunch(launch);
-			}
-		// perform initial pre-launch sanity checks
-			lmonitor.subTask(DebugCoreMessages.LaunchConfiguration_8);
-
-			if (delegate2 != null) {
-				if (!(delegate2.preLaunchCheck(this, mode, lmonitor.split(1)))) {
-					getLaunchManager().removeLaunch(launch);
-					return launch;
-				}
-			}
-			lmonitor.setWorkRemaining(22);
-		// perform pre-launch build
-			if (build) {
-				lmonitor.subTask(DebugCoreMessages.LaunchConfiguration_7 + DebugCoreMessages.LaunchConfiguration_6);
-				boolean tempbuild = build;
-				if (delegate2 != null) {
-					tempbuild = delegate2.buildForLaunch(this, mode, lmonitor.split(7));
-				}
-				if (tempbuild) {
-					lmonitor.subTask(DebugCoreMessages.LaunchConfiguration_7 + DebugCoreMessages.LaunchConfiguration_5);
-					ResourcesPlugin.getWorkspace().build(IncrementalProjectBuilder.INCREMENTAL_BUILD, lmonitor.split(3));
-				}
-			}
-			lmonitor.setWorkRemaining(12);
-		// final validation
-			lmonitor.subTask(DebugCoreMessages.LaunchConfiguration_4);
-			if (delegate2 != null) {
-				if (!(delegate2.finalLaunchCheck(this, mode, lmonitor.split(1)))) {
-					getLaunchManager().removeLaunch(launch);
-					return launch;
-				}
-			}
-			lmonitor.setWorkRemaining(11);
-
 			try {
+				if (delegate2 != null) {
+					launch = delegate2.getLaunch(this, mode);
+				}
+				if (launch == null) {
+					launch = new Launch(this, mode, null);
+				} else // ensure the launch mode is valid
+				if (!mode.equals(launch.getLaunchMode())) {
+					IStatus status = new Status(IStatus.ERROR, DebugPlugin.getUniqueIdentifier(), DebugPlugin.ERROR,
+							MessageFormat.format(DebugCoreMessages.LaunchConfiguration_14, mode, launch.getLaunchMode()), null);
+					throw new CoreException(status);
+				}
+				launch.setAttribute(DebugPlugin.ATTR_LAUNCH_TIMESTAMP, Long.toString(System.currentTimeMillis()));
+				boolean captureOutput = getAttribute(DebugPlugin.ATTR_CAPTURE_OUTPUT, true);
+				if (!captureOutput) {
+					launch.setAttribute(DebugPlugin.ATTR_CAPTURE_OUTPUT, "false"); //$NON-NLS-1$
+				} else {
+					launch.setAttribute(DebugPlugin.ATTR_CAPTURE_OUTPUT, null);
+				}
+				if (!getAttribute(DebugPlugin.ATTR_FORCE_SYSTEM_CONSOLE_ENCODING, false)) {
+					launch.setAttribute(DebugPlugin.ATTR_CONSOLE_ENCODING, getLaunchManager().getEncoding(this));
+				}
+				if (register) {
+					getLaunchManager().addLaunch(launch);
+				}
+				// perform initial pre-launch sanity checks
+				lmonitor.subTask(DebugCoreMessages.LaunchConfiguration_8);
+
+				if (delegate2 != null) {
+					if (!(delegate2.preLaunchCheck(this, mode, lmonitor.split(1)))) {
+						getLaunchManager().removeLaunch(launch);
+						return launch;
+					}
+				}
+				lmonitor.setWorkRemaining(22);
+				// perform pre-launch build
+				if (build) {
+					lmonitor.subTask(DebugCoreMessages.LaunchConfiguration_7 + DebugCoreMessages.LaunchConfiguration_6);
+					boolean tempbuild = build;
+					if (delegate2 != null) {
+						tempbuild = delegate2.buildForLaunch(this, mode, lmonitor.split(7));
+					}
+					if (tempbuild) {
+						lmonitor.subTask(DebugCoreMessages.LaunchConfiguration_7 + DebugCoreMessages.LaunchConfiguration_5);
+						ResourcesPlugin.getWorkspace().build(IncrementalProjectBuilder.INCREMENTAL_BUILD, lmonitor.split(3));
+					}
+				}
+				lmonitor.setWorkRemaining(12);
+				// final validation
+				lmonitor.subTask(DebugCoreMessages.LaunchConfiguration_4);
+				if (delegate2 != null) {
+					if (!(delegate2.finalLaunchCheck(this, mode, lmonitor.split(1)))) {
+						getLaunchManager().removeLaunch(launch);
+						return launch;
+					}
+				}
+				lmonitor.setWorkRemaining(11);
+
 				//initialize the source locator
 				lmonitor.subTask(DebugCoreMessages.LaunchConfiguration_3);
 				initializeSourceLocator(launch);
@@ -803,13 +806,13 @@ public class LaunchConfiguration extends PlatformObject implements ILaunchConfig
 				delegate.launch(this, mode, launch, lmonitor.split(10));
 			} catch (CoreException e) {
 				// if there was an exception, and the launch is empty, remove it
-				if (!launch.hasChildren()) {
+				if (launch != null && !launch.hasChildren()) {
 					getLaunchManager().removeLaunch(launch);
 				}
 				throw e;
 			} catch (RuntimeException e) {
 				// if there was a runtime exception, and the launch is empty, remove it
-				if (!launch.hasChildren()) {
+				if (launch != null && !launch.hasChildren()) {
 					getLaunchManager().removeLaunch(launch);
 				}
 				throw e;
@@ -1039,4 +1042,15 @@ public class LaunchConfiguration extends PlatformObject implements ILaunchConfig
 
 		return delegate;
 	}
+
+	protected String getLineSeparator() throws CoreException {
+		IFile file = getFile();
+		if (file != null) {
+			// file is in workspace
+			return file.getLineSeparator(true);
+		}
+
+		// file is not in workspace, use platform default
+		return System.lineSeparator();
+	}
 }
