@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -284,12 +284,10 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 								if (registered != null) {
 									registered.add(fNotifierLaunches[j]);
 								}
-							} else {
-								if (registered == null) {
-									registered = new ArrayList<>(fNotifierLaunches.length);
-									for (int k = 0; k < j; k++) {
-										registered.add(fNotifierLaunches[k]);
-									}
+							} else if (registered == null) {
+								registered = new ArrayList<>(fNotifierLaunches.length);
+								for (int k = 0; k < j; k++) {
+									registered.add(fNotifierLaunches[k]);
 								}
 							}
 						}
@@ -444,7 +442,7 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 	 * Collects files whose extension matches the launch configuration file
 	 * extension.
 	 */
-	class ResourceProxyVisitor implements IResourceProxyVisitor {
+	static class ResourceProxyVisitor implements IResourceProxyVisitor {
 
 		private List<IResource> fList;
 
@@ -455,7 +453,7 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 		@Override
 		public boolean visit(IResourceProxy proxy) {
 			if (proxy.getType() == IResource.FILE) {
-				if (ILaunchConfiguration.LAUNCH_CONFIGURATION_FILE_EXTENSION.equalsIgnoreCase(proxy.requestFullPath().getFileExtension()) | ILaunchConfiguration.LAUNCH_CONFIGURATION_PROTOTYPE_FILE_EXTENSION.equalsIgnoreCase(proxy.requestFullPath().getFileExtension())) {
+				if (ILaunchConfiguration.LAUNCH_CONFIGURATION_FILE_EXTENSION.equalsIgnoreCase(proxy.requestFullPath().getFileExtension()) || ILaunchConfiguration.LAUNCH_CONFIGURATION_PROTOTYPE_FILE_EXTENSION.equalsIgnoreCase(proxy.requestFullPath().getFileExtension())) {
 					fList.add(proxy.requestResource());
 				}
 				return false;
@@ -469,7 +467,7 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 	 *
 	 * @since 3.3
 	 */
-	class PreferredDelegate {
+	static class PreferredDelegate {
 		private ILaunchDelegate fDelegate = null;
 		private String fTypeid = null;
 		private Set<String> fModes = null;
@@ -514,6 +512,7 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 	 */
 	public static final IPath LOCAL_LAUNCH_CONFIGURATION_CONTAINER_PATH =
 		DebugPlugin.getDefault().getStateLocation().append(".launches"); //$NON-NLS-1$
+
 	/**
 	 * Returns a Document that can be used to build a DOM tree
 	 * @return the Document
@@ -523,8 +522,7 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 	public static Document getDocument() throws ParserConfigurationException {
 		DocumentBuilderFactory dfactory= DocumentBuilderFactory.newInstance();
 		DocumentBuilder docBuilder= dfactory.newDocumentBuilder();
-		Document doc= docBuilder.newDocument();
-		return doc;
+		return docBuilder.newDocument();
 	}
 
 	/**
@@ -538,6 +536,21 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 	 * @throws IOException if I/O error occurs
 	 */
 	public static String serializeDocument(Document doc) throws TransformerException, IOException {
+		return serializeDocument(doc, System.lineSeparator());
+	}
+
+	/**
+	 * Serializes a XML document into a string - encoded in UTF8 format, with
+	 * specified line separator.
+	 *
+	 * @param doc document to serialize
+	 * @param lineDelimiter the new line separator to use
+	 * @return the document as a string
+	 * @throws TransformerException if an unrecoverable error occurs during the
+	 *             serialization
+	 * @throws IOException if I/O error occurs
+	 */
+	public static String serializeDocument(Document doc, String lineDelimiter) throws TransformerException, IOException {
 		ByteArrayOutputStream s = new ByteArrayOutputStream();
 		TransformerFactory factory = TransformerFactory.newInstance();
 		Transformer transformer = factory.newTransformer();
@@ -546,7 +559,7 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 		DOMSource source = new DOMSource(doc);
 		StreamResult outputTarget = new StreamResult(s);
 		transformer.transform(source, outputTarget);
-		return s.toString(StandardCharsets.UTF_8);
+		return s.toString(StandardCharsets.UTF_8).replace(System.lineSeparator(), lineDelimiter);
 	}
 
 	/**
@@ -851,6 +864,10 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 
 	@Override
 	public String getEncoding(ILaunchConfiguration configuration) throws CoreException {
+		boolean forceSystemEncoding = configuration.getAttribute(DebugPlugin.ATTR_FORCE_SYSTEM_CONSOLE_ENCODING, false);
+		if (forceSystemEncoding) {
+			return Platform.getSystemCharset().name();
+		}
 		String encoding = configuration.getAttribute(DebugPlugin.ATTR_CONSOLE_ENCODING, (String)null);
 		if(encoding == null) {
 			IResource[] resources = configuration.getMappedResources();
@@ -948,7 +965,7 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 	 */
 	protected List<ILaunchConfiguration> findLaunchConfigurations(IContainer container) {
 		if (container instanceof IProject && !((IProject)container).isOpen()) {
-			return Collections.EMPTY_LIST;
+			return Collections.emptyList();
 		}
 		List<IResource> list = new ArrayList<>(10);
 		ResourceProxyVisitor visitor= new ResourceProxyVisitor(list);
@@ -1015,7 +1032,7 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 			}
 			return configs;
 		}
-		return Collections.EMPTY_LIST;
+		return Collections.emptyList();
 	}
 
 	/**
@@ -1120,7 +1137,7 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 	 *
 	 * @return all launch configuration handles
 	 */
-	private synchronized List<ILaunchConfiguration> getAllLaunchConfigurations() {
+	public synchronized List<ILaunchConfiguration> getAllLaunchConfigurations() {
 		if (fLaunchConfigurationIndex == null) {
 			try {
 				fLaunchConfigurationIndex = new ArrayList<>(20);
@@ -1366,13 +1383,11 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 					}
 				}
 
+			} else if (store != null){
+				throw createDebugException(MessageFormat.format(DebugCoreMessages.LaunchManager_does_not_exist, new Object[] {
+						config.getName(), store.toURI().toString() }), null);
 			} else {
-				if (store != null){
-					throw createDebugException(MessageFormat.format(DebugCoreMessages.LaunchManager_does_not_exist, new Object[] {
-							config.getName(), store.toURI().toString() }), null);
-				} else {
-					throw createDebugException(MessageFormat.format(DebugCoreMessages.LaunchManager_does_not_exist_no_store_found, new Object[] { config.getName() }), null);
-				}
+				throw createDebugException(MessageFormat.format(DebugCoreMessages.LaunchManager_does_not_exist_no_store_found, new Object[] { config.getName() }), null);
 			}
 		}
 		return info;
@@ -1666,7 +1681,7 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 		// compatibility.
 		initializePreferredDelegates();
 		for (PreferredDelegate pd : fPreferredDelegates) {
-			if(pd.getModes().equals(modes) & pd.getTypeId().equals(typeid)) {
+			if (pd.getModes().equals(modes) && pd.getTypeId().equals(typeid)) {
 				return pd.getDelegate();
 			}
 		}
@@ -2397,7 +2412,7 @@ public class LaunchManager extends PlatformObject implements ILaunchManager, IRe
 		try {
 			for (ILaunch launch : launches) {
 				for (ILaunchConfiguration config : configs) {
-					if(config.equals(launch.getLaunchConfiguration()) & launch.canTerminate()) {
+					if (config.equals(launch.getLaunchConfiguration()) && launch.canTerminate()) {
 						launch.terminate();
 					}
 				}
