@@ -13,6 +13,12 @@
  *******************************************************************************/
 package org.eclipse.debug.tests.console;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.LinkedList;
@@ -32,6 +38,7 @@ import org.eclipse.swt.custom.TextChangeListener;
 import org.eclipse.swt.custom.TextChangedEvent;
 import org.eclipse.swt.custom.TextChangingEvent;
 import org.eclipse.ui.internal.console.ConsoleDocumentAdapter;
+import org.junit.Test;
 
 /**
  * Tests {@link ConsoleDocumentAdapter}.
@@ -42,17 +49,10 @@ import org.eclipse.ui.internal.console.ConsoleDocumentAdapter;
 @SuppressWarnings("restriction")
 public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 
-	public ConsoleDocumentAdapterTests() {
-		super(ConsoleDocumentAdapterTests.class.getSimpleName());
-	}
-
-	public ConsoleDocumentAdapterTests(String name) {
-		super(name);
-	}
-
 	/**
 	 * Test {@link ConsoleDocumentAdapter#setText(String)}.
 	 */
+	@Test
 	public void testSetText() {
 		final ExpectingTextChangeListener eventListener = new ExpectingTextChangeListener(true, null);
 		final IDocumentAdapter docAdapter = new ConsoleDocumentAdapter(-1);
@@ -77,6 +77,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 	/**
 	 * Test fixed width line wrap. (mostly with changes affecting a single line)
 	 */
+	@Test
 	public void testLineWrap() {
 		final Random rand = new Random(4);
 		final int wrapWidth = 10;
@@ -199,7 +200,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 
 		// add text starting at fixed width border
 		addText = "kl";
-		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, null, null, null, null, 0, 1));
+		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, docAdapter.getCharCount(), addText, 0, addText.length(), 0, 1));
 		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGED));
 		docAdapter.replaceTextRange(docAdapter.getCharCount(), 0, addText);
 		assertNumberOfLines(docAdapter, 5);
@@ -213,7 +214,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 		// insert text starting at fixed width border
 		addText = ">";
 		offset = docAdapter.getCharCount() - 2;
-		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, null, null, null, null, 1, 1));
+		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, offset, addText, 0, addText.length(), 0, 0));
 		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGED));
 		docAdapter.replaceTextRange(offset, 0, addText);
 		assertNumberOfLines(docAdapter, 5);
@@ -225,7 +226,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 		checkLineMapping(docAdapter, rand);
 
 		// delete character at fixed width border
-		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, null, null, null, null, 1, 1));
+		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, offset, "", 1, 0, 0, 0));
 		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGED));
 		docAdapter.replaceTextRange(offset, 1, "");
 		assertNumberOfLines(docAdapter, 5);
@@ -338,7 +339,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 		docAdapter.replaceTextRange(offset, 0, addText);
 		replaceText = "uvwxyz_-=|";
 		offset = docAdapter.getCharCount() - 3;
-		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, null, null, null, null, 1, 1));
+		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, offset, replaceText, 3, replaceText.length(), 0, 0));
 		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGED));
 		docAdapter.replaceTextRange(offset, 3, replaceText);
 		assertNumberOfLines(docAdapter, 7);
@@ -357,7 +358,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 
 		// remove last wrapped line
 		offset = docAdapter.getOffsetAtLine(docAdapter.getLineCount() - 1);
-		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, null, null, null, null, 1, 0));
+		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, offset, "", 10, 0, 1, 0));
 		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGED));
 		docAdapter.replaceTextRange(offset, 10, "");
 		assertNumberOfLines(docAdapter, 6);
@@ -376,7 +377,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 
 		// remove 5th line including it's real line delimiter
 		offset = docAdapter.getOffsetAtLine(5 - 1);
-		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, null, null, null, null, null, null));
+		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, offset, "", 11, 0, 1, 0));
 		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGED));
 		docAdapter.replaceTextRange(offset, 11, "");
 		assertNumberOfLines(docAdapter, 5);
@@ -406,6 +407,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 	/**
 	 * Test inserting text containing line delimiters.
 	 */
+	@Test
 	public void testMultilineInserts() {
 		final Random rand = new Random(4);
 		final int wrapWidth = 10;
@@ -577,6 +579,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 	/**
 	 * Test text remove affecting than one line.
 	 */
+	@Test
 	public void testMultilineRemove() {
 		final Random rand = new Random(4);
 		final int wrapWidth = 10;
@@ -637,7 +640,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 		// remove at fixed width border
 		offset = 10;
 		remove = 1;
-		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, null, null, null, null, 1, 0));
+		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, offset, "", remove, 0, 1, 0));
 		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGED));
 		docAdapter.replaceTextRange(offset, remove, "");
 		assertNumberOfLines(docAdapter, 1);
@@ -701,6 +704,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 	/**
 	 * Test text change affecting and inserting more than one line.
 	 */
+	@Test
 	public void testMultilineReplace() {
 		final Random rand = new Random(4);
 		final int wrapWidth = 10;
@@ -763,6 +767,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 		assertLine(docAdapter, 3, "#B");
 		checkLineMapping(docAdapter, rand);
 
+		// replace last (real) line with new content
 		addText = "*+";
 		offset = docAdapter.getCharCount() - 2;
 		length = 1;
@@ -774,6 +779,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 		assertLine(docAdapter, 3, "*+B");
 		checkLineMapping(docAdapter, rand);
 
+		// replace last character (at fixed width border) with new content
 		docAdapter.setText("");
 		docAdapter.replaceTextRange(docAdapter.getCharCount(), 0, "0123456789");
 		docAdapter.replaceTextRange(docAdapter.getCharCount(), 0, "ABCDEFGHIJ");
@@ -781,7 +787,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 		addText = "$b";
 		offset = docAdapter.getCharCount() - 1;
 		length = 1;
-		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, null, null, null, null, 1, 1));
+		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGING, offset, addText, length, addText.length(), 0, 0));
 		eventListener.addExpectation(new TextEventExpectation(TextChangeEventType.CHANGED));
 		docAdapter.replaceTextRange(offset, length, addText);
 		assertNumberOfLines(docAdapter, 3);
@@ -795,6 +801,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 	/**
 	 * Test line wrapping is correctly updated if fixed width changed.
 	 */
+	@Test
 	public void testSetWidth() {
 		final Random rand = new Random(7);
 		final ConsoleDocumentAdapter docAdapter = new ConsoleDocumentAdapter(-1);
@@ -861,6 +868,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 	 * Some test cases derived from JavaDoc examples of {@link IDocumentAdapter}
 	 * (and its super interfaces).
 	 */
+	@Test
 	public void testInterfaceContract() {
 		final ConsoleDocumentAdapter docAdapter = new ConsoleDocumentAdapter(-1);
 		docAdapter.setDocument(new Document());
@@ -907,6 +915,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 	 * {@link IDocumentAdapter#setDocument(org.eclipse.jface.text.IDocument)}
 	 * and ensure old document is indeed disconnected and not notified anymore.
 	 */
+	@Test
 	public void testChangeDocument() {
 		final IDocumentAdapter docAdapter = new ConsoleDocumentAdapter(-1);
 		final IDocument doc1 = new Document();
@@ -1025,6 +1034,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 	/**
 	 * Test adapter with a larger number of lines. (especially tests array grow)
 	 */
+	@Test
 	public void testManyLines() {
 		final ConsoleDocumentAdapter docAdapter = new ConsoleDocumentAdapter(80);
 		docAdapter.setDocument(new Document());
@@ -1164,6 +1174,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 		 * and {@link #docAdapter} is set do some additional validations.
 		 */
 		TextChangingEvent lastEvent;
+		int eventLineBeforeChange = -1;
 		int linesBeforeReplace = -1;
 		int lengthBeforeReplace = -1;
 
@@ -1180,31 +1191,30 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 		@Override
 		public void textChanging(TextChangingEvent event) {
 			final TextEventExpectation expectation = checkCommon(TextChangeEventType.CHANGING);
-			if (expectation == null) {
-				return;
-			}
-
-			if (expectation.start != null) {
-				assertEquals("event.start", (int) expectation.start, event.start);
-			}
-			if (expectation.newText != null) {
-				assertEquals("event.newText", expectation.newText, event.newText);
-			}
-			if (expectation.replaceCharCount != null) {
-				assertEquals("event.replaceCharCount", (int) expectation.replaceCharCount, event.replaceCharCount);
-			}
-			if (expectation.newCharCount != null) {
-				assertEquals("event.newCharCount", (int) expectation.newCharCount, event.newCharCount);
-			}
-			if (expectation.replaceLineCount != null) {
-				assertEquals("event.replaceLineCount", (int) expectation.replaceLineCount, event.replaceLineCount);
-			}
-			if (expectation.newLineCount != null) {
-				assertEquals("event.newLineCount", (int) expectation.newLineCount, event.newLineCount);
+			if (expectation != null) {
+				if (expectation.start != null) {
+					assertEquals("event.start", (int) expectation.start, event.start);
+				}
+				if (expectation.newText != null) {
+					assertEquals("event.newText", expectation.newText, event.newText);
+				}
+				if (expectation.replaceCharCount != null) {
+					assertEquals("event.replaceCharCount", (int) expectation.replaceCharCount, event.replaceCharCount);
+				}
+				if (expectation.newCharCount != null) {
+					assertEquals("event.newCharCount", (int) expectation.newCharCount, event.newCharCount);
+				}
+				if (expectation.replaceLineCount != null) {
+					assertEquals("event.replaceLineCount", (int) expectation.replaceLineCount, event.replaceLineCount);
+				}
+				if (expectation.newLineCount != null) {
+					assertEquals("event.newLineCount", (int) expectation.newLineCount, event.newLineCount);
+				}
 			}
 
 			if (!allowUnexpectedEvents && docAdapter != null) {
 				lastEvent = event;
+				eventLineBeforeChange = docAdapter.getLineAtOffset(event.start);
 				linesBeforeReplace = docAdapter.getLineCount();
 				lengthBeforeReplace = docAdapter.getCharCount();
 
@@ -1223,7 +1233,7 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 			if (docAdapter != null && lastEvent != null) {
 				final int lastEventOffset = lastEvent.start;
 				final int lastEventLineIndex = docAdapter.getLineAtOffset(lastEventOffset);
-				assertEquals("Line of offset " + lastEventOffset + " has changed after text change.", lastEventLineIndex, docAdapter.getLineAtOffset(lastEventOffset));
+				assertTrue("Line of event offset " + lastEventOffset + " has moved up.", eventLineBeforeChange <= lastEventLineIndex);
 
 				// check if predicted changes are correct
 				final int predictedDocLength = lengthBeforeReplace - lastEvent.replaceCharCount + lastEvent.newCharCount;
@@ -1249,10 +1259,6 @@ public class ConsoleDocumentAdapterTests extends AbstractDebugTest {
 				return null;
 			}
 			assertNotNull("Unexpected event.", expectation);
-			if (expectation == null) {
-				// prevents wrong compiler warning 'expectation may be null'
-				return null;
-			}
 			if (expectation.type != eventType && allowUnexpectedEvents) {
 				return null;
 			}
