@@ -23,6 +23,10 @@ import org.junit.Test;
 
 public class LaunchViewSmokeTest extends AbstractLaunchViewTest {
 
+	@SuppressWarnings({ "restriction", "unused" })
+	// Only ensures org.eclipse.debug.ui.launchview is required
+	private static final org.eclipse.debug.ui.launchview.IBackgroundLaunchExecutor e = null;
+
 	@Test
 	public void testOpenView() {
 		IWorkbenchPage page = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
