@@ -21,6 +21,7 @@ import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.wizard.WizardDialog;
 import org.eclipse.swt.widgets.Event;
+import org.eclipse.ui.PlatformUI;
 
 /**
  * This class provides the aciton event for both the context menu in breakpoints view
@@ -44,7 +45,7 @@ public class ImportBreakpoints extends AbstractDebugActionDelegate {
 	@Override
 	public void run(IAction action) {
 		WizardImportBreakpoints wiz = new WizardImportBreakpoints();
-		wiz.init(DebugUIPlugin.getDefault().getWorkbench(), null);
+		wiz.init(PlatformUI.getWorkbench(), null);
 		WizardDialog wizdialog = new WizardDialog(DebugUIPlugin.getShell(), wiz);
 		wizdialog.setBlockOnOpen(true);
 		wizdialog.open();
