@@ -17,9 +17,10 @@
 package org.eclipse.debug.internal.ui.launchConfigurations;
 
 import java.lang.reflect.InvocationTargetException;
+import java.text.MessageFormat;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.Set;
 
 import org.eclipse.core.runtime.CoreException;
@@ -60,7 +61,6 @@ import org.eclipse.jface.operation.ModalContext;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.util.IPropertyChangeListener;
 import org.eclipse.jface.util.PropertyChangeEvent;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.StructuredSelection;
@@ -92,8 +92,7 @@ import org.eclipse.swt.widgets.ToolBar;
 import org.eclipse.swt.widgets.TreeItem;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.progress.WorkbenchJob;
-
-import com.ibm.icu.text.MessageFormat;
+import org.osgi.framework.FrameworkUtil;
 
 /**
  * The dialog used to edit and launch launch configurations.
@@ -234,6 +233,7 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 	private DeletedProjectFilter fDeletedProjectFilter;
 	private LaunchConfigurationTypeFilter fLCTFilter;
 	private WorkingSetsFilter fWorkingSetsFilter;
+	private UniqueLaunchConfigurationFileFilter fUniqueLaunchConfugurationFileFilter;
 
 	/**
 	 * set of reserved names that should not be considered when generating a new name for a launch configuration
@@ -346,11 +346,11 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 
 	@Override
 	public boolean close() {
-	    if (!isSafeToClose()) {
-	        return false;
-	    }
-	    persistSashWeights();
-	    persistExpansion();
+		if (!isSafeToClose()) {
+			return false;
+		}
+		persistSashWeights();
+		persistExpansion();
 		setCurrentlyVisibleLaunchConfigurationDialog(null);
 		fTabViewer.dispose();
 		if (fLaunchConfigurationView != null) {
@@ -394,9 +394,9 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 		composite.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
 		composite.setFont(font);
 		// create help control if needed
-        if (isHelpAvailable()) {
-        	createHelpControl(composite);
-        }
+		if (isHelpAvailable()) {
+			createHelpControl(composite);
+		}
 		Composite monitorComposite = new Composite(composite, SWT.NULL);
 		layout = new GridLayout();
 		layout.marginHeight = 0;
@@ -447,7 +447,7 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 	@Override
 	protected void createButtonsForButtonBar(Composite parent) {
 		Button button = createButton(parent, ID_LAUNCH_BUTTON, getLaunchButtonText(), true);
-        button.setEnabled(false);
+		button.setEnabled(false);
 		Listener[] listeners = button.getListeners(SWT.Selection);
 		for (Listener listener : listeners) {
 			button.removeListener(SWT.Selection, listener);
@@ -528,26 +528,26 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 	 * @return the composite used for launch configuration selection area
 	 */
 	protected Control createLaunchConfigurationSelectionArea(Composite parent) {
-        Composite comp = new Composite(parent, SWT.FLAT);
-        GridLayout gridLayout = new GridLayout(1, false);
-        gridLayout.marginHeight = 0;
-        gridLayout.marginWidth = 0;
-        comp.setLayout(gridLayout);
-        comp.setLayoutData(new GridData(GridData.FILL_BOTH));
+		Composite comp = new Composite(parent, SWT.FLAT);
+		GridLayout gridLayout = new GridLayout(1, false);
+		gridLayout.marginHeight = 0;
+		gridLayout.marginWidth = 0;
+		comp.setLayout(gridLayout);
+		comp.setLayoutData(new GridData(GridData.FILL_BOTH));
 
-        ViewForm viewForm = new ViewForm(comp, SWT.FLAT | SWT.BORDER);
-        ToolBarManager toolBarManager= new ToolBarManager(SWT.FLAT);
-        ToolBar toolBar = toolBarManager.createControl(viewForm);
-        toolBar.setBackground(parent.getBackground());
-        viewForm.setTopLeft(toolBar);
-        viewForm.setLayoutData(new GridData(GridData.FILL_BOTH));
+		ViewForm viewForm = new ViewForm(comp, SWT.FLAT | SWT.BORDER);
+		ToolBarManager toolBarManager= new ToolBarManager(SWT.FLAT);
+		ToolBar toolBar = toolBarManager.createControl(viewForm);
+		toolBar.setBackground(parent.getBackground());
+		viewForm.setTopLeft(toolBar);
+		viewForm.setLayoutData(new GridData(GridData.FILL_BOTH));
 
-        Composite viewFormContents = new Composite(viewForm, SWT.FLAT);
-        gridLayout = new GridLayout();
-        gridLayout.marginHeight = 5;
-        gridLayout.marginWidth = 5;
-        viewFormContents.setLayout(gridLayout);
-        viewFormContents.setBackground(parent.getDisplay().getSystemColor(SWT.COLOR_LIST_BACKGROUND));
+		Composite viewFormContents = new Composite(viewForm, SWT.FLAT);
+		gridLayout = new GridLayout();
+		gridLayout.marginHeight = 5;
+		gridLayout.marginWidth = 5;
+		viewFormContents.setLayout(gridLayout);
+		viewFormContents.setBackground(parent.getDisplay().getSystemColor(SWT.COLOR_LIST_BACKGROUND));
 		fLaunchConfigurationView = new LaunchConfigurationView(getLaunchGroup(), createViewerFilters());
 		fLaunchConfigurationView.createLaunchDialogControl(viewFormContents);
 		Text filterText = fLaunchConfigurationView.getFilteringTextControl();
@@ -588,21 +588,18 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 		Control control = viewer.getControl();
 		GridData gd = new GridData(GridData.FILL_BOTH);
 		control.setLayoutData(gd);
-        viewForm.setContent(viewFormContents);
-		AbstractLaunchConfigurationAction.IConfirmationRequestor requestor = new AbstractLaunchConfigurationAction.IConfirmationRequestor() {
-			@Override
-			public boolean getConfirmation() {
-				int status = shouldSaveCurrentConfig();
-				if(status == IDialogConstants.YES_ID) {
-					fTabViewer.handleApplyPressed();
-					return true;
-				}
-				else if(status == IDialogConstants.NO_ID) {
-					fTabViewer.handleRevertPressed();
-					return true;
-				}
-				return false;
+		viewForm.setContent(viewFormContents);
+		AbstractLaunchConfigurationAction.IConfirmationRequestor requestor = () -> {
+			int status = shouldSaveCurrentConfig();
+			if(status == IDialogConstants.YES_ID) {
+				fTabViewer.handleApplyPressed();
+				return true;
 			}
+			else if(status == IDialogConstants.NO_ID) {
+				fTabViewer.handleRevertPressed();
+				return true;
+			}
+			return false;
 		};
 		getDuplicateAction().setConfirmationRequestor(requestor);
 		getExportAction().setConfirmationRequestor(requestor);
@@ -611,19 +608,16 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 		getLinkPrototypeAction().setConfirmationRequestor(requestor);
 		getUnlinkPrototypeAction().setConfirmationRequestor(requestor);
 		getResetWithPrototypeValuesAction().setConfirmationRequestor(requestor);
-		((StructuredViewer) viewer).addPostSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				handleLaunchConfigurationSelectionChanged(event);
-				getNewAction().setEnabled(getNewAction().isEnabled());
-				getNewPrototypeAction().setEnabled(getNewPrototypeAction().isEnabled());
-				getDeleteAction().setEnabled(getDeleteAction().isEnabled());
-				getExportAction().setEnabled(getExportAction().isEnabled());
-				getDuplicateAction().setEnabled(getDuplicateAction().isEnabled());
-				getLinkPrototypeAction().setEnabled(getLinkPrototypeAction().isEnabled());
-				getUnlinkPrototypeAction().setEnabled(getUnlinkPrototypeAction().isEnabled());
-				getResetWithPrototypeValuesAction().setEnabled(getResetWithPrototypeValuesAction().isEnabled());
-			}
+		((StructuredViewer) viewer).addPostSelectionChangedListener(event -> {
+			handleLaunchConfigurationSelectionChanged(event);
+			getNewAction().setEnabled(getNewAction().isEnabled());
+			getNewPrototypeAction().setEnabled(getNewPrototypeAction().isEnabled());
+			getDeleteAction().setEnabled(getDeleteAction().isEnabled());
+			getExportAction().setEnabled(getExportAction().isEnabled());
+			getDuplicateAction().setEnabled(getDuplicateAction().isEnabled());
+			getLinkPrototypeAction().setEnabled(getLinkPrototypeAction().isEnabled());
+			getUnlinkPrototypeAction().setEnabled(getUnlinkPrototypeAction().isEnabled());
+			getResetWithPrototypeValuesAction().setEnabled(getResetWithPrototypeValuesAction().isEnabled());
 		});
 		return comp;
 	}
@@ -652,6 +646,8 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 		if(DebugUIPlugin.getDefault().getPreferenceStore().getBoolean(IInternalDebugUIConstants.PREF_FILTER_WORKING_SETS)) {
 			filters.add(fWorkingSetsFilter);
 		}
+		fUniqueLaunchConfugurationFileFilter = new UniqueLaunchConfigurationFileFilter();
+		filters.add(fUniqueLaunchConfugurationFileFilter);
 		return filters.toArray(new ViewerFilter[filters.size()]);
 	}
 
@@ -734,18 +730,18 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 
 	/*
 	 * @see org.eclipse.jface.dialogs.Dialog#getDialogBoundsSettings()
-	 * 
+	 *
 	 * @since 3.2
 	 */
-    @Override
+	@Override
 	protected IDialogSettings getDialogBoundsSettings() {
-    	return getDialogSettings();
-    }
+		return getDialogSettings();
+	}
 
-    @Override
+	@Override
 	protected int getDialogBoundsStrategy() {
-    	return DIALOG_PERSISTSIZE;
-    }
+		return DIALOG_PERSISTSIZE;
+	}
 
 	/**
 	 * Returns the dialog settings for this dialog. Subclasses should override
@@ -754,7 +750,9 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 	 * @return IDialogSettings
 	 */
 	protected IDialogSettings getDialogSettings() {
-		IDialogSettings settings = DebugUIPlugin.getDefault().getDialogSettings();
+		IDialogSettings settings = PlatformUI
+				.getDialogSettingsProvider(FrameworkUtil.getBundle(LaunchConfigurationDialog.class))
+				.getDialogSettings();
 		IDialogSettings section = settings.getSection(getDialogSettingsSectionName());
 		if (section == null) {
 			section = settings.addNewSection(getDialogSettingsSectionName());
@@ -784,12 +782,12 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 		return DebugUIPlugin.getStandardDisplay();
 	}
 
-  	/**
-  	 * Gets the duplicate menu action
-  	 *
-  	 * @return the duplicate menu action
-  	 */
-  	protected AbstractLaunchConfigurationAction getDuplicateAction() {
+	/**
+	 * Gets the duplicate menu action
+	 *
+	 * @return the duplicate menu action
+	 */
+	protected AbstractLaunchConfigurationAction getDuplicateAction() {
 		return (AbstractLaunchConfigurationAction)fLaunchConfigurationView.getAction(DuplicateLaunchConfigurationAction.ID_DUPLICATE_ACTION);
 	}
 
@@ -811,7 +809,7 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 		return IDebugHelpContextIds.LAUNCH_CONFIGURATION_DIALOG;
 	}
 
- 	/**
+	/**
 	 * Returns the status the dialog was opened on or <code>null</code> if none.
 	 *
 	 * @return IStatus
@@ -820,7 +818,7 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 		return fInitialStatus;
 	}
 
- 	/**
+	/**
 	 * Return the last launched configuration in the workspace.
 	 *
 	 * @return the last launched configuration
@@ -829,7 +827,7 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 		return DebugUIPlugin.getDefault().getLaunchConfigurationManager().getLastLaunch(getLaunchGroup().getIdentifier());
 	}
 
- 	/**
+	/**
 	 * Returns the appropriate text for the launch button - run or debug.
 	 *
 	 * @return the launch button text
@@ -838,7 +836,7 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 		return DebugPlugin.getDefault().getLaunchManager().getLaunchMode(getMode()).getLabel();
 	}
 
- 	/**
+	/**
 	 * Returns the launch group being displayed.
 	 *
 	 * @return launch group
@@ -847,10 +845,10 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 		return fGroup;
 	}
 
- 	@Override
+	@Override
 	public String getMode() {
- 		return getLaunchGroup().getMode();
- 	}
+		return getLaunchGroup().getMode();
+	}
 
 	/**
 	 * Gets the new menu action
@@ -944,24 +942,24 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 	}
 
 	/**
- 	 * Returns the current tab group
- 	 *
- 	 * @return the current tab group, or <code>null</code> if none
- 	 */
- 	public ILaunchConfigurationTabGroup getTabGroup() {
- 		if (fTabViewer != null) {
- 			return fTabViewer.getTabGroup();
- 		}
- 		return null;
- 	}
+	 * Returns the current tab group
+	 *
+	 * @return the current tab group, or <code>null</code> if none
+	 */
+	public ILaunchConfigurationTabGroup getTabGroup() {
+		if (fTabViewer != null) {
+			return fTabViewer.getTabGroup();
+		}
+		return null;
+	}
 
- 	@Override
+	@Override
 	public ILaunchConfigurationTab[] getTabs() {
- 		if (getTabGroup() == null) {
- 			return null;
- 		}
- 		return getTabGroup().getTabs();
- 	}
+		if (getTabGroup() == null) {
+			return null;
+		}
+		return getTabGroup().getTabs();
+	}
 
 	/**
 	 * Returns the viewer used to display the tabs for a launch configuration.
@@ -1001,43 +999,43 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 	 *
 	 * @param event selection changed event
 	 */
- 	protected void handleLaunchConfigurationSelectionChanged(SelectionChangedEvent event) {
- 		Object input = fTabViewer.getInput();
- 		Object newInput = null;
+	protected void handleLaunchConfigurationSelectionChanged(SelectionChangedEvent event) {
+		Object input = fTabViewer.getInput();
+		Object newInput = null;
 		IStructuredSelection selection = event.getStructuredSelection();
- 		if (selection.size() == 1) {
+		if (selection.size() == 1) {
 			newInput = selection.getFirstElement();
- 		}
- 		if (!isEqual(input, newInput)) {
- 			ILaunchConfiguration original = fTabViewer.getOriginal();
- 	 		if (original != null && newInput == null && getLaunchManager().getMovedTo(original) != null) {
- 				return;
- 			}
- 			boolean deleted = false;
- 			if (original != null) {
- 				deleted = !original.exists();
- 			}
+		}
+		if (!isEqual(input, newInput)) {
+			ILaunchConfiguration original = fTabViewer.getOriginal();
+			if (original != null && newInput == null && getLaunchManager().getMovedTo(original) != null) {
+				return;
+			}
+			boolean deleted = false;
+			if (original != null) {
+				deleted = !original.exists();
+			}
 			boolean renamed = false;
 			if (newInput instanceof ILaunchConfiguration) {
 				renamed = getLaunchManager().getMovedFrom((ILaunchConfiguration)newInput) != null;
 			}
 			try {
 				fSettingInput = true;
-	 			if (fTabViewer.canSave() && fTabViewer.isDirty() && !deleted && !renamed) {
-	 				if(fLaunchConfigurationView != null) {
-	 					fLaunchConfigurationView.setAutoSelect(false);
-	 				}
-	 				int ret = showUnsavedChangesDialog();
-	 				if(ret == IDialogConstants.YES_ID) {
-	 					fTabViewer.handleApplyPressed();
+				if (fTabViewer.canSave() && fTabViewer.isDirty() && !deleted && !renamed) {
+					if(fLaunchConfigurationView != null) {
+						fLaunchConfigurationView.setAutoSelect(false);
+					}
+					int ret = showUnsavedChangesDialog();
+					if(ret == IDialogConstants.YES_ID) {
+						fTabViewer.handleApplyPressed();
 						ILaunchConfigurationTab[] tabs = getTabs();
 						if (tabs != null) {
 							for (ILaunchConfigurationTab tab : tabs) {
 								tab.postApply();
 							}
 						}
-	 					fTabViewer.setInput(newInput);
-	 				}
+						fTabViewer.setInput(newInput);
+					}
 					else if(ret == IDialogConstants.NO_ID) {
 						fTabViewer.handleRevertPressed();
 						fTabViewer.setInput(newInput);
@@ -1045,24 +1043,24 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 					else {
 						fLaunchConfigurationView.getViewer().setSelection(new StructuredSelection(input));
 					}
-	 				fLaunchConfigurationView.setAutoSelect(true);
-	  			}
-	 			else {
-	 				fTabViewer.setInput(newInput);
-	 				if(fTabViewer.isDirty()) {
-	 					fTabViewer.handleApplyPressed();
-	 				}
-	 			}
+					fLaunchConfigurationView.setAutoSelect(true);
+				}
+				else {
+					fTabViewer.setInput(newInput);
+					if(fTabViewer.isDirty()) {
+						fTabViewer.handleApplyPressed();
+					}
+				}
 			} finally {
 				fSettingInput = false;
 				updateButtons();
 				updateMessage();
 			}
- 			if(getShell() != null && getShell().isVisible()) {
- 				resize();
- 			}
- 		}
-  	}
+			if(getShell() != null && getShell().isVisible()) {
+				resize();
+			}
+		}
+		}
 
 	/**
 	 * Notification the 'launch' button has been pressed. Save and launch.
@@ -1158,8 +1156,8 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 			ILaunchConfigurationDialog dialog = LaunchConfigurationsDialog.getCurrentlyVisibleLaunchConfigurationDialog();
 			tabGroup.createTabs(dialog, dialog.getMode());
 			ILaunchConfigurationTab[] tabs = tabGroup.getTabs();
-			for (int i = 0; i < tabs.length; i++) {
-				tabs[i].setLaunchConfigurationDialog(dialog);
+			for (ILaunchConfigurationTab tab : tabs) {
+				tab.setLaunchConfigurationDialog(dialog);
 			}
 			tabGroup.setDefaults(wc);
 			tabGroup.dispose();
@@ -1201,14 +1199,14 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 	 * @return true if they are equal, false if object 1 is null, the result of o1.equals(o2) otherwise
 	 */
 	protected boolean isEqual(Object o1, Object o2) {
-  		if (o1 == o2) {
-  			return true;
-  		} else if (o1 == null) {
-  			return false;
-  		} else {
-  			return o1.equals(o2);
-  		}
-  	}
+		if (o1 == o2) {
+			return true;
+		} else if (o1 == null) {
+			return false;
+		} else {
+			return o1.equals(o2);
+		}
+	}
 
 	/**
 	 * Returns whether the dialog can be closed
@@ -1216,7 +1214,7 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 	 * @return whether the dialog can be closed
 	 */
 	protected boolean isSafeToClose() {
-	    return fActiveRunningOperations == 0;
+		return fActiveRunningOperations == 0;
 	}
 
 	/**
@@ -1254,25 +1252,22 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 			}
 			ArrayList<String> list = new ArrayList<>();
 			String[] persisted = value.split(DELIMITER);
-			for(int i = 0; i < persisted.length; i++) {
-				list.add(persisted[i]);
-			}
+			Collections.addAll(list, persisted);
 			String type = IInternalDebugCoreConstants.EMPTY_STRING;
 			//if the item is not in the list and is expanded add it, otherwise if it
 			//is not expanded do a remove...either way for the else we query the list
-			for(int i = 0; i < items.length; i++) {
-				type = ((ILaunchConfigurationType)items[i].getData()).getIdentifier();
-				if(!list.contains(type) & items[i].getExpanded()) {
+			for (TreeItem item : items) {
+				type = ((ILaunchConfigurationType) item.getData()).getIdentifier();
+				if (!list.contains(type) & item.getExpanded()) {
 					list.add(type);
-				}
-				else if(!items[i].getExpanded()) {
+				} else if (!item.getExpanded()) {
 					list.remove(type);
 				}
 			}
 			value = IInternalDebugCoreConstants.EMPTY_STRING;
 			//build the preference string
-			for (Iterator<String> iter = list.iterator(); iter.hasNext();) {
-				value += iter.next() + DELIMITER;
+			for (String segment : list) {
+				value += segment + DELIMITER;
 			}
 			settings.put(DIALOG_EXPANDED_NODES, value);
 		}
@@ -1303,10 +1298,10 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 						catch (CoreException e) {DebugUIPlugin.log(e);}
 					}
 				}
-				for(int i = 0; i < nodes.length; i++) {
-					for(int k = 0; k < items.length; k++) {
-						ILaunchConfigurationType type = (ILaunchConfigurationType)items[k].getData();
-						if(type.getIdentifier().equals(nodes[i])) {
+				for (String node : nodes) {
+					for (TreeItem item : items) {
+						ILaunchConfigurationType type = (ILaunchConfigurationType) item.getData();
+						if (type.getIdentifier().equals(node)) {
 							toexpand.add(type);
 						}
 					}
@@ -1342,24 +1337,27 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 	 * @since 3.13
 	 */
 	public void refreshLaunchConfigurationView() {
-		fLaunchConfigurationView.getTreeViewer().refresh();
+		LaunchConfigurationView view = fLaunchConfigurationView;
+		if (view != null) {
+			view.getTreeViewer().refresh();
+		}
 	}
 
 	/**
 	 * resize the dialog to show all relevant content
 	 */
 	protected void resize() {
- 		if(getTabGroup() != null) {
+		if(getTabGroup() != null) {
 			Point shell = getShell().getSize();
- 			int maxx = (int)(getDisplay().getBounds().width * MAX_DIALOG_WIDTH_PERCENT),
+			int maxx = (int)(getDisplay().getBounds().width * MAX_DIALOG_WIDTH_PERCENT),
 				maxy = (int) (getDisplay().getBounds().height * MAX_DIALOG_HEIGHT_PERCENT);
- 			maxx = (maxx < DEFAULT_INITIAL_DIALOG_SIZE.x ? DEFAULT_INITIAL_DIALOG_SIZE.x : maxx);
- 			maxy = (maxy < DEFAULT_INITIAL_DIALOG_SIZE.y ? DEFAULT_INITIAL_DIALOG_SIZE.y : maxy);
- 			Point psize = getShell().computeSize(SWT.DEFAULT, maxy);
- 			if((psize.x > maxx ? maxx : psize.x) > shell.x || (psize.y > maxy ? maxy : psize.y) > shell.y) {
+			maxx = (maxx < DEFAULT_INITIAL_DIALOG_SIZE.x ? DEFAULT_INITIAL_DIALOG_SIZE.x : maxx);
+			maxy = (maxy < DEFAULT_INITIAL_DIALOG_SIZE.y ? DEFAULT_INITIAL_DIALOG_SIZE.y : maxy);
+			Point psize = getShell().computeSize(SWT.DEFAULT, maxy);
+			if((psize.x > maxx ? maxx : psize.x) > shell.x || (psize.y > maxy ? maxy : psize.y) > shell.y) {
 				setShellSize(Math.min(psize.x, maxx), Math.min(psize.y, maxy));
 				constrainShellSize();
- 			}
+			}
 		}
 	}
 
@@ -1512,9 +1510,9 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 	}
 
 	/**
- 	 * Increase the size of this dialog's <code>Shell</code> by the specified amounts.
- 	 * Do not increase the size of the Shell beyond the bounds of the Display.
- 	 */
+	 * Increase the size of this dialog's <code>Shell</code> by the specified amounts.
+	 * Do not increase the size of the Shell beyond the bounds of the Display.
+	 */
 	protected void setShellSize(int width, int height) {
 		Rectangle bounds = getShell().getMonitor().getBounds();
 		getShell().setSize(Math.min(width, bounds.width), Math.min(height, bounds.height));
@@ -1538,7 +1536,7 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 	 * <code>IDialogConstants</code>.
 	 */
 	private int showDiscardChangesDialog() {
-		StringBuffer buffer = new StringBuffer(MessageFormat.format(LaunchConfigurationsMessages.LaunchConfigurationDialog_The_configuration___35, new Object[] { fTabViewer.getWorkingCopy().getName() }));
+		StringBuilder buffer = new StringBuilder(MessageFormat.format(LaunchConfigurationsMessages.LaunchConfigurationDialog_The_configuration___35, new Object[] { fTabViewer.getWorkingCopy().getName() }));
 		buffer.append(fTabViewer.getErrorMesssage());
 		buffer.append(LaunchConfigurationsMessages.LaunchConfigurationDialog_Do_you_wish_to_discard_changes_37);
 		MessageDialog dialog = new MessageDialog(getShell(),
@@ -1660,7 +1658,7 @@ public class LaunchConfigurationsDialog extends TitleAreaDialog implements ILaun
 			@Override
 			public IStatus runInUIThread(IProgressMonitor monitor) {
 				TreeViewer viewer = fLaunchConfigurationView.getTreeViewer();
-				boolean newvalue = Boolean.valueOf(event.getNewValue().toString()).booleanValue();
+				boolean newvalue = Boolean.parseBoolean(event.getNewValue().toString());
 				if(event.getProperty().equals(IInternalDebugUIConstants.PREF_FILTER_LAUNCH_CLOSED)) {
 					updateFilter(newvalue, fClosedProjectFilter);
 				}
