@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2006, 2017 IBM Corporation and others.
+ * Copyright (c) 2006, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -35,6 +35,7 @@ import org.eclipse.jface.viewers.IBaseLabelProvider;
 import org.eclipse.jface.viewers.IContentProvider;
 import org.eclipse.jface.viewers.ILabelProvider;
 import org.eclipse.jface.viewers.IStructuredContentProvider;
+import org.eclipse.jface.viewers.LabelProvider;
 import org.eclipse.jface.viewers.StructuredViewer;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.SelectionAdapter;
@@ -49,7 +50,6 @@ import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.ide.IDE;
 import org.eclipse.ui.model.AdaptableList;
 import org.eclipse.ui.model.WorkbenchContentProvider;
-import org.eclipse.ui.model.WorkbenchLabelProvider;
 
 /**
  * Status handler to prompt for saving of resources prior to launching.
@@ -169,27 +169,27 @@ public class SaveScopeResourcesHandler implements IStatusHandler {
 				 projects = (IProject[]) objects[1];
 			}
 		}
-        if (config != null) {
-            if (DebugUITools.isPrivate(config)) {
-                return Boolean.TRUE;
-            }
-        }
-        if (projects != null && projects.length > 0) {
-            IPreferenceStore store = DebugUIPlugin.getDefault().getPreferenceStore();
-            String save = store.getString(IInternalDebugUIConstants.PREF_SAVE_DIRTY_EDITORS_BEFORE_LAUNCH);
-            int ret = showSaveDialog(projects, !save.equals(MessageDialogWithToggle.NEVER), save.equals(MessageDialogWithToggle.PROMPT));
-            if(ret == IDialogConstants.OK_ID) {
-            	doSave();
-            	return Boolean.TRUE;
-            }
-            return Boolean.FALSE;
-        }
-        else {
+		if (config != null) {
+			if (DebugUITools.isPrivate(config)) {
+				return Boolean.TRUE;
+			}
+		}
+		if (projects != null && projects.length > 0) {
+			IPreferenceStore store = DebugUIPlugin.getDefault().getPreferenceStore();
+			String save = store.getString(IInternalDebugUIConstants.PREF_SAVE_DIRTY_EDITORS_BEFORE_LAUNCH);
+			int ret = showSaveDialog(projects, !save.equals(MessageDialogWithToggle.NEVER), save.equals(MessageDialogWithToggle.PROMPT));
+			if(ret == IDialogConstants.OK_ID) {
+				doSave();
+				return Boolean.TRUE;
+			}
+			return Boolean.FALSE;
+		}
+		else {
 			@SuppressWarnings("deprecation")
 			boolean cancel = DebugUIPlugin.preLaunchSave();
-            return Boolean.valueOf(cancel);
-        }
-    }
+			return Boolean.valueOf(cancel);
+		}
+	}
 
 	/**
 	 *
@@ -201,15 +201,15 @@ public class SaveScopeResourcesHandler implements IStatusHandler {
 	protected IResource[] getScopedDirtyResources(IProject[] projects) {
 		HashSet<IResource> dirtyres = new HashSet<>();
 		IWorkbenchWindow[] windows = PlatformUI.getWorkbench().getWorkbenchWindows();
-		for(int l = 0; l < windows.length; l++) {
-			IWorkbenchPage[] pages = windows[l].getPages();
-			for(int i = 0; i < pages.length; i++) {
-				IEditorPart[] eparts = pages[i].getDirtyEditors();
-				for(int j = 0; j < eparts.length; j++) {
-					IResource resource = eparts[j].getEditorInput().getAdapter(IResource.class);
-					if(resource != null) {
-						for(int k = 0; k < projects.length; k++) {
-							if(projects[k].equals(resource.getProject())) {
+		for (IWorkbenchWindow window : windows) {
+			IWorkbenchPage[] pages = window.getPages();
+			for (IWorkbenchPage page : pages) {
+				IEditorPart[] eparts = page.getDirtyEditors();
+				for (IEditorPart epart : eparts) {
+					IResource resource = epart.getEditorInput().getAdapter(IResource.class);
+					if (resource != null) {
+						for (IProject project : projects) {
+							if (project.equals(resource.getProject())) {
 								dirtyres.add(resource);
 							}
 						}
@@ -244,7 +244,7 @@ public class SaveScopeResourcesHandler implements IStatusHandler {
 				ScopedResourcesSelectionDialog lsd = new ScopedResourcesSelectionDialog(DebugUIPlugin.getShell(),
 						new AdaptableList(resources),
 						new WorkbenchContentProvider(),
-						new WorkbenchLabelProvider());
+						new SaveResourceDialogWorkbenchLabelProvider());
 				lsd.setInitialSelections((Object[]) resources);
 				lsd.setTitle(LaunchConfigurationsMessages.SaveScopeResourcesHandler_3);
 				if(lsd.open() == IDialogConstants.CANCEL_ID) {
@@ -262,4 +262,17 @@ public class SaveScopeResourcesHandler implements IStatusHandler {
 		}
 		return IDialogConstants.OK_ID;
 	}
+
 }
+
+
+class SaveResourceDialogWorkbenchLabelProvider extends LabelProvider {
+	@Override
+	public final String getText(Object element) {
+		if (element instanceof IResource) {
+			return ((IResource)element).getFullPath().toString();
+		}
+		return super.getText(element);
+	}
+
+}
\ No newline at end of file
