@@ -42,12 +42,8 @@ import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.dialogs.MessageDialogWithToggle;
 import org.eclipse.jface.preference.PreferencePage;
 import org.eclipse.jface.preference.RadioGroupFieldEditor;
-import org.eclipse.jface.viewers.DoubleClickEvent;
-import org.eclipse.jface.viewers.IDoubleClickListener;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.ITreeContentProvider;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.viewers.TreeViewer;
 import org.eclipse.swt.SWT;
@@ -131,7 +127,7 @@ public class LaunchPerspectivePreferencePage extends PreferencePage implements I
 	/**
 	 * Provides content for the configuration tree viewer
 	 */
-	final class PerspectiveContentProvider implements ITreeContentProvider {
+	static final class PerspectiveContentProvider implements ITreeContentProvider {
 		@Override
 		public Object[] getChildren(Object parentElement) {
 			if(parentElement instanceof ILaunchConfigurationType) {
@@ -328,20 +324,12 @@ public class LaunchPerspectivePreferencePage extends PreferencePage implements I
 		gd.heightHint = 250;
 		fTree.setLayoutData(gd);
 		fTreeViewer = new PerspectivesTreeViewer(fTree);
-		fTreeViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				fPerspectivesPanel.refreshPanel(event.getStructuredSelection());
-			}
-		});
-		fTreeViewer.addDoubleClickListener(new IDoubleClickListener() {
-			@Override
-			public void doubleClick(DoubleClickEvent event) {
-				IStructuredSelection ss = (IStructuredSelection) event.getSelection();
-				if(!ss.isEmpty()) {
-					Object obj = ss.getFirstElement();
-					fTreeViewer.setExpandedState(obj, !fTreeViewer.getExpandedState(obj));
-				}
+		fTreeViewer.addSelectionChangedListener(event -> fPerspectivesPanel.refreshPanel(event.getStructuredSelection()));
+		fTreeViewer.addDoubleClickListener(event -> {
+			IStructuredSelection ss = (IStructuredSelection) event.getSelection();
+			if(!ss.isEmpty()) {
+				Object obj = ss.getFirstElement();
+				fTreeViewer.setExpandedState(obj, !fTreeViewer.getExpandedState(obj));
 			}
 		});
 		fTreeViewer.setLabelProvider(DebugUITools.newDebugModelPresentation());
@@ -370,7 +358,7 @@ public class LaunchPerspectivePreferencePage extends PreferencePage implements I
 			fmodes = LaunchConfigurationPresentationManager.getDefault().getLaunchModeNames(smodes);
 			if(!fmodes.isEmpty()) {
 				//add the mode set and create a combo
-				String modeString= fmodes.size() == 1 ? fmodes.get(0).toString() : fmodes.toString();
+				String modeString= fmodes.size() == 1 ? fmodes.get(0) : fmodes.toString();
 				SWTFactory.createLabel(parent, modeString + ":", 1); //$NON-NLS-1$
 				combo = SWTFactory.createCombo(parent, SWT.READ_ONLY, 1, fgPerspectiveLabels);
 				if(combo == null) {
@@ -468,27 +456,22 @@ public class LaunchPerspectivePreferencePage extends PreferencePage implements I
 
 	//prep selection context, remove types from the equation
 		HashSet<ILaunchDelegate> delegates = new HashSet<>();
-		Object o = null;
-		for(int i = 0; i < selection.length; i++) {
-			o = selection[i];
+		for (Object o : selection) {
 			if(o instanceof ILaunchDelegate) {
 				delegates.add((ILaunchDelegate) o);
 			}
 			else if(o instanceof ILaunchConfigurationType) {
 				fgCurrentWorkingContext.add(o);
-				Object[] kids = fTreeViewer.getFilteredChildren(o);
-				for (int j = 0; j < kids.length; j++) {
-					delegates.add((ILaunchDelegate) kids[i]);
+				for (Object kid : fTreeViewer.getFilteredChildren(o)) {
+					delegates.add((ILaunchDelegate) kid);
 				}
 			}
 		}
 	//compare the listing of delegates to find common mode sets
 		HashSet<Set<String>> common = new HashSet<>();
-		List<Set<String>> modes = null;
 		HashSet<Set<String>> pruned = new HashSet<>();
 		for (ILaunchDelegate delegate : delegates) {
-			modes = delegate.getModes();
-			for (Set<String> fmodes : modes) {
+			for (Set<String> fmodes : delegate.getModes()) {
 				if (isCommonModeset(fmodes, delegates, pruned)) {
 					common.add(fmodes);
 					fgCurrentWorkingContext.add(delegate);
@@ -544,21 +527,14 @@ public class LaunchPerspectivePreferencePage extends PreferencePage implements I
 		fSwitchSuspend.loadDefault();
 
 		PerspectiveManager pm = DebugUIPlugin.getDefault().getPerspectiveManager();
-		TreeItem[] items = fTree.getItems();
-		ILaunchConfigurationType type = null;
-		Set<Set<String>> modes = null;
-		Object[] delegates = null;
-		for(int i = 0; i < items.length; i++) {
-			type = (ILaunchConfigurationType) items[i].getData();
-			modes = type.getSupportedModeCombinations();
-			delegates = fTreeViewer.getFilteredChildren(type);
-			for (Set<String> modeset : modes) {
+		for (TreeItem item : fTree.getItems()) {
+			ILaunchConfigurationType type = (ILaunchConfigurationType) item.getData();
+			for (Set<String> modeset : type.getSupportedModeCombinations()) {
 				fgChangeSet.add(new PerspectiveChange(type, null, modeset, pm.getDefaultLaunchPerspective(type, null, modeset)));
 			}
-			for(int j = 0; j < delegates.length; j++) {
-				ILaunchDelegate delegate = (ILaunchDelegate) delegates[j];
-				modes = new HashSet<>(delegate.getModes());
-				for (Set<String> modeset : modes) {
+			for (Object child : fTreeViewer.getFilteredChildren(type)) {
+				ILaunchDelegate delegate = (ILaunchDelegate) child;
+				for (Set<String> modeset : new HashSet<>(delegate.getModes())) {
 					fgChangeSet.add(new PerspectiveChange(type, delegate, modeset, pm.getDefaultLaunchPerspective(type, delegate, modeset)));
 				}
 			}
@@ -580,13 +556,12 @@ public class LaunchPerspectivePreferencePage extends PreferencePage implements I
 		ArrayList<String> labels = new ArrayList<>();
 		labels.add(DebugPreferencesMessages.PerspectivePreferencePage_4);
 		IPerspectiveRegistry registry = PlatformUI.getWorkbench().getPerspectiveRegistry();
-		IPerspectiveDescriptor[] descriptors = registry.getPerspectives();
 		String label = null;
-		for(int i = 0; i < descriptors.length; i++) {
-			if(!WorkbenchActivityHelper.filterItem(descriptors[i])) {
-				label = descriptors[i].getLabel();
+		for (IPerspectiveDescriptor descriptor : registry.getPerspectives()) {
+			if(!WorkbenchActivityHelper.filterItem(descriptor)) {
+				label = descriptor.getLabel();
 				labels.add(label);
-				fgPerspectiveIdMap.put(label, descriptors[i].getId());
+				fgPerspectiveIdMap.put(label, descriptor.getId());
 			}
 		}
 		fgPerspectiveLabels = labels.toArray(new String[labels.size()]);
