@@ -53,8 +53,7 @@ public class ViewContextManager implements IWindowListener {
 	private ViewContextManager() {
 		IWorkbench workbench = PlatformUI.getWorkbench();
 		IWorkbenchWindow[] workbenchWindows = workbench.getWorkbenchWindows();
-		for (int i = 0; i < workbenchWindows.length; i++) {
-			IWorkbenchWindow window = workbenchWindows[i];
+		for (IWorkbenchWindow window : workbenchWindows) {
 			windowOpened(window);
 		}
 		workbench.addWindowListener(this);
