@@ -37,8 +37,7 @@ public class ConsoleRemoveAllTerminatedAction extends Action implements IUpdate,
 	@Override
 	public synchronized void update() {
 		ILaunch[] launches = DebugPlugin.getDefault().getLaunchManager().getLaunches();
-		for (int i = 0; i < launches.length; i++) {
-			ILaunch launch = launches[i];
+		for (ILaunch launch : launches) {
 			if (launch.isTerminated()) {
 				setEnabled(true);
 				return;
@@ -65,20 +64,20 @@ public class ConsoleRemoveAllTerminatedAction extends Action implements IUpdate,
 		update();
 	}
 
-    @Override
+	@Override
 	public void launchesRemoved(ILaunch[] launches) {
-       if (isEnabled()) {
-           update();
-       }
-    }
+		if (isEnabled()) {
+			update();
+		}
+	}
 
-    @Override
+	@Override
 	public void launchesAdded(ILaunch[] launches) {
-    }
+	}
 
-    @Override
+	@Override
 	public void launchesChanged(ILaunch[] launches) {
-    }
+	}
 
 	@Override
 	public void launchesTerminated(ILaunch[] launches) {
