@@ -31,7 +31,6 @@ import org.eclipse.debug.core.model.IMemoryBlockRetrieval;
 import org.eclipse.debug.internal.core.IInternalDebugCoreConstants;
 import org.eclipse.debug.internal.ui.DebugUIMessages;
 import org.eclipse.debug.ui.DebugUITools;
-import org.eclipse.debug.ui.contexts.DebugContextEvent;
 import org.eclipse.debug.ui.contexts.IDebugContextListener;
 import org.eclipse.debug.ui.memory.IMemoryRendering;
 import org.eclipse.jface.action.Action;
@@ -127,12 +126,9 @@ public class SwitchMemoryBlockAction extends Action implements IViewActionDelega
 	/**
 	 * Listens for debug context changes and updates action delegate enablement
 	 */
-	private IDebugContextListener fDebugContextListener = new IDebugContextListener() {
-		@Override
-		public void debugContextChanged(DebugContextEvent event) {
-			if (fAction != null) {
-				fUpdateJob.schedule();
-			}
+	private IDebugContextListener fDebugContextListener = event -> {
+		if (fAction != null) {
+			fUpdateJob.schedule();
 		}
 	};
 
@@ -174,7 +170,7 @@ public class SwitchMemoryBlockAction extends Action implements IViewActionDelega
 		}
 
 		private void getLabels(final IMemoryBlock memBlk) {
-			StringBuffer text = new StringBuffer(IInternalDebugCoreConstants.EMPTY_STRING);
+			StringBuilder text = new StringBuilder(IInternalDebugCoreConstants.EMPTY_STRING);
 			String label = new String(IInternalDebugCoreConstants.EMPTY_STRING);
 			if (memBlk instanceof IMemoryBlockExtension) {
 				String expression = ((IMemoryBlockExtension) memBlk).getExpression();
@@ -237,9 +233,9 @@ public class SwitchMemoryBlockAction extends Action implements IViewActionDelega
 					allMemoryBlocks = DebugPlugin.getDefault().getMemoryBlockManager().getMemoryBlocks(retrieval);
 				}
 				if (allMemoryBlocks != null) {
-					for (int i = 0; i < allMemoryBlocks.length; i++) {
-						SwitchToAction action = new SwitchToAction(allMemoryBlocks[i], true);
-						if (allMemoryBlocks[i] == memoryBlock) {
+					for (IMemoryBlock block : allMemoryBlocks) {
+						SwitchToAction action = new SwitchToAction(block, true);
+						if (block == memoryBlock) {
 							action.setChecked(true);
 						}
 						ActionContributionItem item = new ActionContributionItem(action);
