@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007 IBM Corporation and others.
+ * Copyright (c) 2007, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -11,6 +11,7 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     David Pickens - [Memory View] Endian in hex view and ASCII view doesn't work
+ *     John Dallaway - Accommodate addressableSize != 1 (bug 575413)
  *******************************************************************************/
 package org.eclipse.debug.internal.ui.views.memory.renderings;
 
@@ -33,27 +34,24 @@ public class HexIntegerRendering extends AbstractIntegerRendering {
 	@Override
 	public String getString(String dataType, BigInteger address,
 			MemoryByte[] data) {
-		StringBuffer strBuffer = new StringBuffer();
+		StringBuilder strBuffer = new StringBuilder();
 		int endianess = getEndianness(data);
 
 		String paddedStr = DebugUIPlugin.getDefault().getPreferenceStore().getString(IDebugUIConstants.PREF_PADDED_STR);
 
-        if (endianess == RenderingsUtil.LITTLE_ENDIAN) {
-            MemoryByte[] swapped = new MemoryByte[data.length];
-            for (int i = 0; i < data.length; i++){
-                swapped[data.length-i-1] = data[i];
-            }
-            data = swapped;
-        }
-
-		for (int i=0; i<data.length; i++)
-		{
-			if (data[i].isReadable())
-			{
-				strBuffer.append(new String(RenderingsUtil.convertByteToCharArray(data[i].getValue())));
+		if (endianess == RenderingsUtil.LITTLE_ENDIAN) {
+			int addressableSize = getAddressableSize();
+			MemoryByte[] swapped = new MemoryByte[data.length];
+			for (int i = 0; i < data.length; i += addressableSize) {
+				System.arraycopy(data, i, swapped, data.length - i - addressableSize, addressableSize);
 			}
-			else
-			{
+			data = swapped;
+		}
+
+		for (MemoryByte memByte : data) {
+			if (memByte.isReadable()) {
+				strBuffer.append(new String(RenderingsUtil.convertByteToCharArray(memByte.getValue())));
+			} else {
 				// pad with padded string
 				strBuffer.append(paddedStr);
 			}
@@ -62,20 +60,20 @@ public class HexIntegerRendering extends AbstractIntegerRendering {
 		return strBuffer.toString().toUpperCase();
 	}
 
-    /**
-     * @todo davidp needs to add a method comment.
-     * @param data
-     * @return
-     */
-    private int getEndianness (MemoryByte[] data) {
-        // if the user has not set an endianess to the rendering
-        // take default
-        int endianess = getDisplayEndianess();
-        if (endianess == RenderingsUtil.ENDIANESS_UNKNOWN) {
+	/**
+	 * @todo davidp needs to add a method comment.
+	 * @param data
+	 * @return
+	 */
+	private int getEndianness (MemoryByte[] data) {
+		// if the user has not set an endianess to the rendering
+		// take default
+		int endianess = getDisplayEndianess();
+		if (endianess == RenderingsUtil.ENDIANESS_UNKNOWN) {
 			endianess = getBytesEndianess(data);
 		}
-        return endianess;
-    }
+		return endianess;
+	}
 
 	@Override
 	public byte[] getBytes(String dataType, BigInteger address,
@@ -85,13 +83,14 @@ public class HexIntegerRendering extends AbstractIntegerRendering {
 		byte[] bytes = RenderingsUtil.convertHexStringToByteArray(data, currentValues.length, getNumCharsPerByte());
 
 
-        if (endianess == RenderingsUtil.LITTLE_ENDIAN) {
-            byte[] swapped = new byte[bytes.length];
-            for (int i = 0; i < bytes.length; i++){
-                swapped[bytes.length-i-1] = bytes[i];
-            }
-           bytes = swapped;
-        }
+		if (endianess == RenderingsUtil.LITTLE_ENDIAN) {
+			int addressableSize = getAddressableSize();
+			byte[] swapped = new byte[bytes.length];
+			for (int i = 0; i < bytes.length; i += addressableSize) {
+				System.arraycopy(bytes, i, swapped, bytes.length - i - addressableSize, addressableSize);
+			}
+			bytes = swapped;
+		}
 
 		return bytes;
 	}
