@@ -80,22 +80,20 @@ public class PrintTableRenderingAction extends Action
 		lineNum = printColumnLabels(printGC, lineNum);
 
 		//for all items in the table
-		for (int i=0; i < itemList.length; i++) {
-			StringBuffer tableContents = new StringBuffer();
+		for (TableItem item : itemList) {
+			StringBuilder tableContents = new StringBuilder();
 			//print all columns for this row
-			for (int j=0; j < numColumns; j++) {
-				String columnText = labelProvider.getColumnText(itemList[i].getData(), j);
-
+			for (int j = 0; j < numColumns; j++) {
+				String columnText = labelProvider.getColumnText(item.getData(), j);
 				while (columnText.length() < fRendering.getBytesPerColumn() * charsPerByte)
 				{
-					 columnText += " "; //$NON-NLS-1$
+					columnText += " "; //$NON-NLS-1$
 				}
 				tableContents.append(COLUMN_SEPERATOR);
 				tableContents.append(columnText);
 			}
 			printGC.drawString(tableContents.toString(), 10, 10+(lineNum*printGC.getFontMetrics().getHeight()));
 			lineNum++;
-
 			// if we've run over the end of a page, start a new one
 			if (20+lineNum*printGC.getFontMetrics().getHeight() > printer.getClientArea().height) {
 				lineNum=1;
@@ -108,7 +106,7 @@ public class PrintTableRenderingAction extends Action
 
 	private int printColumnLabels(GC printGC, int lineNum)
 	{
-		StringBuffer tableContents = new StringBuffer();
+		StringBuilder tableContents = new StringBuilder();
 		int numColumns = ((Table)fViewer.getControl()).getColumnCount();
 		TableColumn columns[] = ((Table)fViewer.getControl()).getColumns();
 
@@ -148,7 +146,7 @@ public class PrintTableRenderingAction extends Action
 		//get the column headers
 		for (int k=0; k < numColumns; k++) {
 
-			StringBuffer columnLabel = new StringBuffer(columns[k].getText());
+			StringBuilder columnLabel = new StringBuilder(columns[k].getText());
 			int numBytes = 0;
 
 			if (k > 0)
